summaryrefslogtreecommitdiffstats
path: root/kmail/searchwindow.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-02-01 15:14:12 -0600
commitfd5d099065a748cac49e20a13481f85666c53c71 (patch)
treea0f1672cd88eb0e69b9ddc2ed9b08ecd98538bd3 /kmail/searchwindow.cpp
parentb440a9c608596cd88efdb3bfa4661c5e37efbe4b (diff)
downloadtdepim-fd5d099065a748cac49e20a13481f85666c53c71.tar.gz
tdepim-fd5d099065a748cac49e20a13481f85666c53c71.zip
Rename a number of classes to enhance compatibility with KDE4
Diffstat (limited to 'kmail/searchwindow.cpp')
-rw-r--r--kmail/searchwindow.cpp34
1 files changed, 17 insertions, 17 deletions
diff --git a/kmail/searchwindow.cpp b/kmail/searchwindow.cpp
index 849cba8b..e5c00951 100644
--- a/kmail/searchwindow.cpp
+++ b/kmail/searchwindow.cpp
@@ -67,12 +67,12 @@ namespace KMail {
const int SearchWindow::MSGID_COLUMN = 4;
-// KListView sub-class for dnd support
-class MatchListView : public KListView
+// TDEListView sub-class for dnd support
+class MatchListView : public TDEListView
{
public:
MatchListView( TQWidget *parent, SearchWindow* sw, const char* name = 0 ) :
- KListView( parent, name ),
+ TDEListView( parent, name ),
mSearchWindow( sw )
{}
@@ -213,13 +213,13 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
solves the above problem, but speeds searches with many hits
up considerably. - till
- TODO: subclass KListViewItem and do proper (and performant)
+ TODO: subclass TDEListViewItem and do proper (and performant)
comapare functions
*/
mLbxMatches->setSorting(2, false);
mLbxMatches->setShowSortIndicator(true);
mLbxMatches->setAllColumnsShowFocus(true);
- mLbxMatches->setSelectionModeExt(KListView::Extended);
+ mLbxMatches->setSelectionModeExt(TDEListView::Extended);
mLbxMatches->addColumn(i18n("Subject"),
config->readNumEntry("SubjectWidth", 150));
mLbxMatches->addColumn(i18n("Sender/Receiver"),
@@ -307,27 +307,27 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
kdDebug(5006) << "SearchWindow: regExpLineEdit not found" << endl;
//set up actions
- KActionCollection *ac = actionCollection();
+ TDEActionCollection *ac = actionCollection();
ac->setWidget( this );
- mReplyAction = new KAction( i18n("&Reply..."), "mail_reply", 0, TQT_TQOBJECT(this),
+ mReplyAction = new TDEAction( i18n("&Reply..."), "mail_reply", 0, TQT_TQOBJECT(this),
TQT_SLOT(slotReplyToMsg()), ac, "search_reply" );
- mReplyAllAction = new KAction( i18n("Reply to &All..."), "mail_replyall",
+ mReplyAllAction = new TDEAction( i18n("Reply to &All..."), "mail_replyall",
0, TQT_TQOBJECT(this), TQT_SLOT(slotReplyAllToMsg()),
ac, "search_reply_all" );
- mReplyListAction = new KAction( i18n("Reply to Mailing-&List..."),
+ mReplyListAction = new TDEAction( i18n("Reply to Mailing-&List..."),
"mail_replylist", 0, TQT_TQOBJECT(this),
TQT_SLOT(slotReplyListToMsg()), ac,
"search_reply_list" );
- mForwardActionMenu = new KActionMenu( i18n("Message->","&Forward"),
+ mForwardActionMenu = new TDEActionMenu( i18n("Message->","&Forward"),
"mail_forward", ac,
"search_message_forward" );
connect( mForwardActionMenu, TQT_SIGNAL(activated()), this,
TQT_SLOT(slotForwardInlineMsg()) );
- mForwardAttachedAction = new KAction( i18n("Message->Forward->","As &Attachment..."),
+ mForwardAttachedAction = new TDEAction( i18n("Message->Forward->","As &Attachment..."),
"mail_forward", 0, TQT_TQOBJECT(this),
TQT_SLOT(slotForwardAttachedMsg()), ac,
"search_message_forward_as_attachment" );
- mForwardInlineAction = new KAction( i18n("&Inline..."),
+ mForwardInlineAction = new TDEAction( i18n("&Inline..."),
"mail_forward", 0, TQT_TQOBJECT(this),
TQT_SLOT(slotForwardInlineMsg()), ac,
"search_message_forward_inline" );
@@ -339,22 +339,22 @@ SearchWindow::SearchWindow(KMMainWidget* w, const char* name,
mForwardActionMenu->insert( mForwardInlineAction );
}
- mForwardDigestAction = new KAction( i18n("Message->Forward->","As Di&gest..."),
+ mForwardDigestAction = new TDEAction( i18n("Message->Forward->","As Di&gest..."),
"mail_forward", 0, TQT_TQOBJECT(this),
TQT_SLOT(slotForwardDigestMsg()), ac,
"search_message_forward_as_digest" );
mForwardActionMenu->insert( mForwardDigestAction );
- mRedirectAction = new KAction( i18n("Message->Forward->","&Redirect..."),
+ mRedirectAction = new TDEAction( i18n("Message->Forward->","&Redirect..."),
"mail_forward", 0, TQT_TQOBJECT(this),
TQT_SLOT(slotRedirectMsg()), ac,
"search_message_forward_redirect" );
mForwardActionMenu->insert( mRedirectAction );
mSaveAsAction = KStdAction::saveAs( TQT_TQOBJECT(this), TQT_SLOT(slotSaveMsg()), ac, "search_file_save_as" );
- mSaveAtchAction = new KAction( i18n("Save Attachments..."), "attach", 0,
+ mSaveAtchAction = new TDEAction( i18n("Save Attachments..."), "attach", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotSaveAttachments()), ac, "search_save_attachments" );
mPrintAction = KStdAction::print( TQT_TQOBJECT(this), TQT_SLOT(slotPrintMsg()), ac, "search_print" );
- mClearAction = new KAction( i18n("Clear Selection"), 0, 0, TQT_TQOBJECT(this),
+ mClearAction = new TDEAction( i18n("Clear Selection"), 0, 0, TQT_TQOBJECT(this),
TQT_SLOT(slotClearSelection()), ac, "search_clear_selection" );
mCopyAction = KStdAction::copy( TQT_TQOBJECT(this), TQT_SLOT(slotCopyMsgs()), ac, "search_copy_messages" );
@@ -576,7 +576,7 @@ void SearchWindow::slotAddMsg(int idx)
else
fName = pFolder->name();
- (void)new KListViewItem(mLbxMatches, mLbxMatches->lastItem(),
+ (void)new TDEListViewItem(mLbxMatches, mLbxMatches->lastItem(),
msg->subject(), from, msg->dateIsoStr(),
fName,
TQString::number(mFolder->serNum(idx)));